@@ -1,5 +1,6 @@
 from .autoencoder import H2OAutoEncoderModel
 from .binomial import H2OBinomialModel
+from .binomial_uplift import H2OBinomialUpliftModel
 from .clustering import H2OClusteringModel
 from .confusion_matrix import ConfusionMatrix
 from .dim_reduction import H2ODimReductionModel
@@ -17,7 +18,10 @@ from .metrics_base import H2ODimReductionModelMetrics
 from .metrics_base import H2OMultinomialModelMetrics
 from .metrics_base import H2OOrdinalModelMetrics
 from .metrics_base import H2ORegressionModelMetrics
+from .metrics_base import H2OBinomialUpliftModelMetrics
 
-__all__ = ["H2OAutoEncoderModel", "H2OBinomialModel", "H2OClusteringModel",
-           "ConfusionMatrix", "H2ODimReductionModel", "MetricsBase", "ModelBase",
-           "H2OModelFuture", "H2OSegmentModels"]
+# order here impacts order of presentation in generated documentation
+__all__ = ["ModelBase", "MetricsBase", 
+           "H2OBinomialModel", "H2OMultinomialModel", "H2ORegressionModel", "H2OOrdinalModel",
+           "H2OClusteringModel", "H2ODimReductionModel", "H2OAutoEncoderModel",
+           "ConfusionMatrix", "H2OModelFuture", "H2OSegmentModels", "H2OBinomialUpliftModel"]
